@@ -326,7 +326,7 @@ def __replace(data, replace):
 
 def __pretty(filename):
     if filename.startswith('.pukecache'):
-        return PukeBuffer.getInfo(filename.split('/').pop())
+        return Cache.getInfo(filename.split('/').pop())
     
     return filename
 
