@@ -11,6 +11,7 @@ from puke.Sed import *
 from puke.Console import *
 from puke.FileSystem import *
 from puke.Env import *
+from puke.Cache import *
 
 VERSION = 0.1
 
@@ -111,7 +112,7 @@ def run():
     if options.clearcache:
         console.header("Spring time, cleaning all the vomit around ...")
         console.log("...")
-        if PukeBuffer.clean():
+        if Cache.clean():
             console.confirm("You're good to go !\n")
         else:
             console.confirm("Your room is already tidy, good boy :-) \n")
